Functions for checking whether an object is a linkdat object, a singleton or
a list of such.
Usage
is.linkdat(x)
is.singleton(x)
is.linkdat.list(x)
Arguments
x
Any R object.
Value
For is.linkdat: TRUE if x is a linkdat (or singleton)
object, and FALSE otherwise. For is.singleton: TRUE if x is
a singleton object, and FALSE otherwise. For is.linkdat.list: TRUE
if x is a list of linkdat/singleton objects.
Details
Note that the singleton class inherits from linkdat, so if
x is a singleton, is.linkdat(x) returns TRUE.